import React, { useState } from "react";
import {
  Text,
  View,
  StyleSheet,
  TouchableOpacity,
  ActivityIndicator,
} from "react-native";
import PropTypes from "prop-types";

function DuolingoButton({
  outerContainerStyle = { borderRadius: 8 },
  innerContainerStyle = { paddingVertical: 12, paddingHorizontal: 24 },
  title = "Duolingo Button",
  textStyle = {},
  primaryColor = "#F7BE1F",
  shadowColor = "#BF8E00",
  onPress,
  shadowDepth = 5,
  loaderColor = "#000000",
  loaderSize = 24,
  isLoading = false,
}) {
  const [isPressed, setIsPressed] = useState(false);

  const onPressIn = () => {
    setIsPressed(true);
  };

  const onPressOut = () => {
    setIsPressed(false);
    if (!isLoading) {
      onPress();
    }
  };

  return (
    <TouchableOpacity
      onPressIn={onPressIn}
      onPressOut={onPressOut}
      style={{
        ...outerContainerStyle,
        ...styles.appButtonDefault,
        ...(!isPressed
          ? {
              backgroundColor: shadowColor,
              paddingBottom: shadowDepth,
            }
          : { paddingTop: shadowDepth }),
      }}
    >
      <View
        style={{
          backgroundColor: primaryColor,
          borderRadius: outerContainerStyle.borderRadius,
          ...innerContainerStyle,
        }}
      >
        <Text
          style={{
            ...styles.buttonText,
            ...textStyle,
            ...{ opacity: isLoading ? 0 : 1 },
          }}
        >
          {title}
        </Text>
        {isLoading && (
          <ActivityIndicator
            animating={isLoading}
            size={loaderSize}
            color={loaderColor}
            style={styles.buttonLoaderStyle}
          />
        )}
      </View>
    </TouchableOpacity>
  );
}

const styles = StyleSheet.create({
  appButtonDefault: {
    alignSelf: "center",
    alignItems: "center",
  },
  buttonText: {
    fontSize: 24,
    color: "black",
  },
  buttonLoaderStyle: {
    position: "absolute",
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
  },
});
DuolingoButton.propTypes = {
  title: PropTypes.string,
  textStyle: PropTypes.object,
  innerContainerStyle: PropTypes.object,
  primaryColor: PropTypes.string,
  shadowColor: PropTypes.string,
  icon: PropTypes.any,
  onClickCallback: PropTypes.func,
  shadowDepth: PropTypes.number,
};

export default DuolingoButton;
